*+--------------------------------------------------------------------
*+
*+ Source Module => c:\hmg.3.4.4\0\SETINDEX\\SETINDEX.PRG
*+
*+    Copyright(C) 1983-2020 by Auge & Ohr
*+
*+    Functions: Procedure Main()
*+               Static Procedure BrowseView()
*+               Static Procedure Pre_SetNewIndex()
*+               Static Procedure SetNewIndex()
*+               Static Function SP_GetWahl()
*+               Static Procedure DoMyIndexAction()
*+
*+       Tables: USE ( cDbf )
*+
*+    Reformatted by Click! 2.05.30 on Feb-3-2020 at  9:33 am
*+
*+--------------------------------------------------------------------

#include "HMG.CH"
#include "Directry.ch"
#include "Dbstruct.ch"

//  REQUEST DBFCDX
REQUEST DBFNTX

*+--------------------------------------------------------------------
*+
*+    Procedure Main()
*+
*+--------------------------------------------------------------------
*+
PROCEDURE Main

LOCAL cTitle := "Demo SET INDEX TO"
LOCAL cDbf   := GetFile( { { "xBase DBF", "*.DBF" } }, cTitle )

   BrowseView( cDBF )

RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure BrowseView()
*+
*+    Called from ( setindex.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE BrowseView( cDBF )

LOCAL nPBwide   := INT( 800 / 12 )
LOCAL cWorkArea
LOCAL aStruc
LOCAL i, iMax
LOCAL cType
LOCAL aHead     := {}
LOCAL aFeld     := {}
LOCAL aWide     := {}

   IF FILE( cDBF )
      USE ( cDbf )
      cWorkArea := ALIAS()

      aStruc := DBSTRUCT()
      iMax := LEN( aStruc )
      FOR i := 1 TO iMax
         AADD( aHead, aStruc[ i ] [ DBS_NAME ] )
         AADD( aFeld, aStruc[ i ] [ DBS_NAME ] )

         cType := aStruc[ i ] [ DBS_TYPE ]
         DO CASE
            CASE cType = "D"
               AADD( aWide, 80 )
            CASE cType = "L"
               AADD( aWide, 30 )
            OTHERWISE
               nWide := aStruc[ i ] [ DBS_LEN ]
               IF nWide < 2
                  nWide := 30
               ELSE
                  nWide := nWide * 11
               ENDIF
               AADD( aWide, nWide )
         ENDCASE
      NEXT
   ELSE
      msginfo( "File " + cPath + cDBF + " not found" )
      RETURN
   ENDIF

   DEFINE WINDOW Browse_View ;
              AT 371, 498 ;
              WIDTH 800 ;
              HEIGHT 600 ;
              TITLE cDBF

      DEFINE BROWSE BrowserView
         ROW 10
         COL 10
         WIDTH 764
         HEIGHT 500
         VALUE 0
         WIDTHS aWide
         HEADERS aHead
         WORKAREA &cWorkArea
         FIELDS aFeld
         FONTNAME "Arial"
         FONTSIZE 11
         TOOLTIP ""
         LOCK .T.
         VSCROLLBAR .T.
      END BROWSE

      DEFINE BUTTON Button_F6
         PARENT Browse_View
         ROW 520
         COL nPBwide * 5
         WIDTH nPBwide - 2
         HEIGHT 40
         ACTION Pre_SetNewIndex( cDBF )
         CAPTION "F6 Index"
         FONTNAME "Arial"
         FONTSIZE 10
         TABSTOP .F.
         VISIBLE .T.
      END BUTTON

   END WINDOW

   ON KEY F6 OF Browse_View ACTION Pre_SetNewIndex( cDBF )

   CENTER WINDOW Browse_View
   ACTIVATE WINDOW Browse_View

   IF USED()
      CLOSE
   ENDIF

RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure Pre_SetNewIndex()
*+
*+    Called from ( setindex.prg )   2 - static procedure browseview()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE Pre_SetNewIndex( cDBF )

LOCAL cRet   := ""
LOCAL lRet   := .F.
LOCAL bError := ERRORBLOCK( { | oErr | BREAK( oErr ) } )

   SP_GetWahl( "" )
   SetNewIndex( cDBF )
   cRet := SP_GetWahl()

   IF !EMPTY( cRet )
      BEGIN SEQUENCE
         SET INDEX TO &cRet
         lRet := .T.
      END SEQUENCE
      ERRORBLOCK( bError )

      IF lRet = .F.
         MsgInfo( "Error set Index TO " + CRLF + cRet )
      ENDIF
   ENDIF
RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure SetNewIndex()
*+
*+    Called from ( setindex.prg )   1 - static procedure pre_setnewindex()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE SetNewIndex( cDBF )

LOCAL aDir, i, iMax
LOCAL a2List := {}
LOCAL aSort
LOCAL cPath, nPosi

   nPosi := RAT( "\", cDBF )
   cPath := SUBSTR( cDBF, 1, nPosi )
   ALTD()
   aDir := DIRECTORY( cPath + "*.NTX" )
   aSort := ASORT( aDir,,, { | x, y | x[ F_NAME ] < y[ F_NAME ] } )

   iMax := LEN( aSort )
   FOR i := 1 TO iMax
      AADD( a2List, aSort[ i ] [ F_NAME ] )
   NEXT

   DEFINE WINDOW SetNewIndex ;
              AT 348, 589 ;
              WIDTH 174 ;
              HEIGHT 755 ;
              TITLE "" ;
              NOMINIMIZE ;
              NOMAXIMIZE ;
              NOSIZE

      DEFINE LISTBOX Set_NewIndex
         PARENT SetNewIndex
         ROW 10
         COL 10
         WIDTH 150
         HEIGHT 700
         ITEMS a2List
         VALUE 1
         FONTNAME "Arial"
         FONTSIZE 10
         TOOLTIP ""
         ONDBLCLICK DoMyIndexAction( aSort, cPath )
         TABSTOP .T.
         VISIBLE .T.
         MULTISELECT .T.
      END LISTBOX

   END WINDOW

   ON KEY ESCAPE OF SetNewIndex ACTION SetNewIndex.Release
   CENTER WINDOW SetNewIndex
   SetNewIndex.Set_NewIndex.setfocus()
   ACTIVATE WINDOW SetNewIndex

RETURN

*+--------------------------------------------------------------------
*+
*+    Static Function SP_GetWahl()
*+
*+    Called from ( setindex.prg )   2 - static procedure pre_setnewindex()
*+                                   1 - static procedure domyindexaction()
*+
*+--------------------------------------------------------------------
*+
STATIC FUNCTION SP_GetWahl( cValue )

STATIC cGetWahl := ""
   IF PCOUNT() > 0
      cGetWahl := cValue
   ENDIF
RETURN cGetWahl

*+--------------------------------------------------------------------
*+
*+    Static Procedure DoMyIndexAction()
*+
*+    Called from ( setindex.prg )   1 - static procedure setnewindex()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE DoMyIndexAction( aSort, cPath )

LOCAL bError := ERRORBLOCK( { | oErr | BREAK( oErr ) } )
LOCAL aRow, nRow, i, imax, cItem
LOCAL cRet   := ""
LOCAL aTags  := {}

   aRow := GetProperty( "SetNewIndex", "Set_NewIndex", "Value" )
   IF EMPTY( aRow )
      SetNewIndex.Release
      RETURN
   ENDIF
   imax := LEN( aRow )
   FOR i := 1 TO iMax
      nRow := aRow[ i ]
      cItem := TRIM( aSort[ nRow ] [ 1 ] )
      AADD( aTags, cItem )
      cRet += cPath + cItem
      IF i <> iMax
         cRet += ", "
      ENDIF
   NEXT
   SP_GetWahl( cRet )
   SetNewIndex.Release
RETURN


*+ EOF: SETINDEX.PRG
